@@ -6,7 +6,7 @@ use Cwd;
 use base qw(Module::Install::Base);
 use vars qw($VERSION);
 
-$VERSION = '0.24';
+$VERSION = '0.26';
 
 sub githubmeta {
   my $self = shift;
@@ -14,9 +14,9 @@ sub githubmeta {
   return unless _under_git();
   return unless $self->can_run('git');
   my $remote = shift || 'origin';
-  return unless my ($git_url) = `git config --get remote.$remote.url`;
+  local $ENV{LANG}='C';
+  return unless my ($git_url) = `git remote show -n $remote` =~ /URL: (.*)$/m;
   return unless $git_url =~ /github\.com/; # Not a Github repository
-  chomp $git_url;
   my $http_url = $git_url;
   $git_url =~ s![\w\-]+\@([^:]+):!git://$1/!;
   $http_url =~ s![\w\-]+\@([^:]+):!https://$1/!;
